pub fn load_from_path(
path: impl AsRef<Path>,
converter: &MeshConverter,
scale: Vector<f32>,
) -> Result<Vec<Result<LoadedShape, MeshConverterError>>, MeshLoaderError>Expand description
Loads parry shapes from a file.
Parameters
path: the file’s path.converter: controls how the shapes are computed from the content. In particular, it lets you specify if the computedSharedShapeis a triangle mesh, its convex hull, bounding box, etc.scale: the scaling factor applied to the geometry input to theconverter. This scale will affect at the geometric level theLoadedShape::shape. Note that raw mesh value stored inLoadedShape::raw_meshremains unscaled.